'use strict';
/** @jsx element */

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.name = undefined;
exports.initialState = initialState;
exports.render = render;
exports.afterRender = afterRender;
exports.afterMount = afterMount;

var _magicVirtualElement = require('magic-virtual-element');

var _magicVirtualElement2 = _interopRequireDefault(_magicVirtualElement);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var name = exports.name = 'Swiper';
var Swiper = null;

function initialState(props) {
  return {
    swiper: null
  };
}

function prevClick(e, _ref, setState) {
  var state = _ref.state;

  if (!state.swiper) {
    return;
  }

  state.swiper.slidePrev();
}

function nextClick(e, _ref2, setState) {
  var state = _ref2.state;

  if (!state.swiper) {
    return;
  }

  state.swiper.slideNext();
}

function render(_ref3) {
  var props = _ref3.props;
  var state = _ref3.state;

  var innerContent = props.children.map(function (el, index) {
    return (0, _magicVirtualElement2.default)(
      'div',
      { 'class': 'swiper__slide' },
      el
    );
  });

  return (0, _magicVirtualElement2.default)(
    'div',
    { 'class': 'swiper' },
    (0, _magicVirtualElement2.default)(
      'div',
      { 'class': 'swiper__inner' },
      innerContent
    ),
    (0, _magicVirtualElement2.default)('div', { 'class': 'swiper__arrow swiper__arrow-left', onClick: prevClick }),
    (0, _magicVirtualElement2.default)('div', { 'class': 'swiper__arrow swiper__arrow-right', onClick: nextClick })
  );
}

function afterRender(_ref4, el) {
  var state = _ref4.state;
  var swiper = state.swiper;

  if (swiper) {
    swiper.onResize();
  }
}

function afterMount(_ref5, el, setState) {
  var props = _ref5.props;

  var swiper = null;
  if (!Swiper) {
    Swiper = require('swiper');
  }

  function handleSlideChangeStart() {
    if (swiper && props['onSlideChangeStart']) {
      props['onSlideChangeStart'](swiper.activeIndex);
    }
  }

  function handleSlideChangeEnd() {
    if (swiper && props['onSlideChangeEnd']) {
      props['onSlideChangeEnd'](swiper.activeIndex);
    }
  }

  function handleTransitionStart() {
    if (swiper && props['onTransitionStart']) {
      props['onTransitionStart'](swiper.activeIndex);
    }
  }

  function handleTransitionEnd() {
    if (swiper && props['onTransitionEnd']) {
      props['onTransitionEnd'](swiper.activeIndex);
    }
  }

  swiper = new Swiper(el, {
    wrapperClass: 'swiper__inner',
    slideClass: 'swiper__slide',
    slideActiveClass: 'swiper__slide__active',
    slideVisibleClass: 'swiper__slide__visible',
    slideDuplicateClass: 'swiper__slide__duplicate',
    slideNextClass: 'swiper__slide__next',
    slidePrevClass: 'swiper__slide__prev',
    slidesPerView: props['slides-per-view'],
    centeredSlides: props['centered-slides'],
    initialSlide: props['initial-slide'],
    onSlideChangeStart: handleSlideChangeStart,
    onSlideChangeEnd: handleSlideChangeEnd,
    onTransitionStart: handleTransitionStart,
    onTransitionEnd: handleTransitionEnd,
    onClick: function onClick(swiper, e) {
      // TODO: swiper click
    }
  });

  setState({
    swiper: swiper
  });
}

exports.default = { initialState: initialState, render: render, afterRender: afterRender, afterMount: afterMount };